@@ -28,7 +28,8 @@
 #ifndef NAUTILUS_ZOOM_CONTROL_H
 #define NAUTILUS_ZOOM_CONTROL_H
 
-#include <gtk/gtkeventbox.h>
+#include <gtk/gtk.h>
+#include <libnautilus-private/nautilus-icon-info.h> /* For NautilusZoomLevel */
 
 #define NAUTILUS_TYPE_ZOOM_CONTROL	      (nautilus_zoom_control_get_type ())
 #define NAUTILUS_ZOOM_CONTROL(obj)	      (GTK_CHECK_CAST ((obj), NAUTILUS_TYPE_ZOOM_CONTROL, NautilusZoomControl))
@@ -41,37 +42,40 @@ typedef struct NautilusZoomControlClass NautilusZoomControlClass;
 typedef struct NautilusZoomControlDetails NautilusZoomControlDetails;
 
 struct NautilusZoomControl {
-	GtkEventBox parent;
+	GtkHBox parent;
 	NautilusZoomControlDetails *details;
 };
 
 struct NautilusZoomControlClass {
-	GtkEventBoxClass parent_class;
+	GtkHBoxClass parent_class;
 	
 	void (*zoom_in)		(NautilusZoomControl *control);
 	void (*zoom_out) 	(NautilusZoomControl *control);
-	void (*zoom_to_level) 	(NautilusZoomControl *control);
-	void (*zoom_to_fit) 	(NautilusZoomControl *control);
+	void (*zoom_to_level) 	(NautilusZoomControl *control,
+				 NautilusZoomLevel zoom_level);
+	void (*zoom_to_default)	(NautilusZoomControl *control);
+
+	/* Action signal for keybindings, do not connect to this */
+	void (*change_value)    (NautilusZoomControl *control,
+				 GtkScrollType scroll);
 };
 
-GtkType    nautilus_zoom_control_get_type           (void);
-GtkWidget *nautilus_zoom_control_new                (void);
-
-void       nautilus_zoom_control_set_zoom_level     (NautilusZoomControl *zoom_control,
-						     double               zoom_level);
-void       nautilus_zoom_control_set_parameters     (NautilusZoomControl *zoom_control,
-						     double               min_zoom_level,
-						     double               max_zoom_level,
-						     gboolean             has_min_zoom_level,
-						     gboolean             has_max_zoom_level,
- 						     GList               *zoom_levels);
-
-double     nautilus_zoom_control_get_zoom_level     (NautilusZoomControl *zoom_control);
-double     nautilus_zoom_control_get_min_zoom_level (NautilusZoomControl *zoom_control);
-double     nautilus_zoom_control_get_max_zoom_level (NautilusZoomControl *zoom_control);
-gboolean   nautilus_zoom_control_has_min_zoom_level (NautilusZoomControl *zoom_control);
-gboolean   nautilus_zoom_control_has_max_zoom_level (NautilusZoomControl *zoom_control);
-gboolean   nautilus_zoom_control_can_zoom_in        (NautilusZoomControl *zoom_control);
-gboolean   nautilus_zoom_control_can_zoom_out       (NautilusZoomControl *zoom_control);
+GType             nautilus_zoom_control_get_type           (void);
+GtkWidget *       nautilus_zoom_control_new                (void);
+void              nautilus_zoom_control_set_zoom_level     (NautilusZoomControl *zoom_control,
+							    NautilusZoomLevel    zoom_level);
+void              nautilus_zoom_control_set_parameters     (NautilusZoomControl *zoom_control,
+							    NautilusZoomLevel    min_zoom_level,
+							    NautilusZoomLevel    max_zoom_level,
+							    gboolean             has_min_zoom_level,
+							    gboolean             has_max_zoom_level,
+							    GList               *zoom_levels);
+NautilusZoomLevel nautilus_zoom_control_get_zoom_level     (NautilusZoomControl *zoom_control);
+NautilusZoomLevel nautilus_zoom_control_get_min_zoom_level (NautilusZoomControl *zoom_control);
+NautilusZoomLevel nautilus_zoom_control_get_max_zoom_level (NautilusZoomControl *zoom_control);
+gboolean          nautilus_zoom_control_has_min_zoom_level (NautilusZoomControl *zoom_control);
+gboolean          nautilus_zoom_control_has_max_zoom_level (NautilusZoomControl *zoom_control);
+gboolean          nautilus_zoom_control_can_zoom_in        (NautilusZoomControl *zoom_control);
+gboolean          nautilus_zoom_control_can_zoom_out       (NautilusZoomControl *zoom_control);
 
 #endif /* NAUTILUS_ZOOM_CONTROL_H */
